{% extends 'dedal/base.html' %}

{% load i18n dedal_tags %}

{% block content %}
	<form method="POST">
		{% csrf_token %}
		{% trans "Are you sure?" %}
		<button class="btn btn-success">{% trans "Yes" %}</button>
		<a class="btn btn-primary" href="javascript:history.back()">{% trans "No" %}</a>
	</form>
{% endblock %}
