{% load staticfiles %}
<!DOCTYPE html>
<html>
<head>
	<title>{% block title %}{% endblock %}</title>
	<meta charset="utf-8">
	<meta http-equiv="X-UA-Compatible" content="IE=edge">
	<meta name="viewport" content="width=device-width, initial-scale=1">
	<link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">
</head>
	<body>
		{% block nav %}{% endblock  %}
		<div class="container">
			{% block content %}{% endblock %}
		</div>
		<footer>
			{% block footer %}{% endblock  %}
		</footer>
	</body>
</html>
